@@ -13,6 +13,8 @@ AUTH_API = https://auth.bodo.ai
 
 [PlatformClusterManager]
 BACKEND_API = https://api.bodo.ai/api
+
+[PlatformCatalogManager]
 """
 
 
@@ -49,6 +51,9 @@ KERNEL_CLEANUP_PERIOD_SECONDS = RemoteIKernelsManagerConfig.getint(
 KERNEL_CMD = RemoteIKernelsManagerConfig.get(
     "KERNEL_CMD", "python -m bodo_platform_ipyparallel_kernel -f {connection_file}"
 )
+CLUSTER_USER = RemoteIKernelsManagerConfig.get("CLUSTER_USER", "bodo")
+BASTION_IP = RemoteIKernelsManagerConfig.get("BASTION_IP", None)
+BASTION_USER = RemoteIKernelsManagerConfig.get("BASTION_USER", "ec2-user")
 
 SSHKeysManagerConfig = config["SSHKeysManager"]
 GET_SSH_KEY_SCRIPT = SSHKeysManagerConfig.get("GET_SSH_KEY_SCRIPT")
@@ -96,3 +101,12 @@ RESUME_CLUSTER_MAX_RETRIES = PlatformClusterManagerConfig.getint(
 PAUSE_CLUSTER_MAX_RETRIES = PlatformClusterManagerConfig.getint(
     "PAUSE_CLUSTER_MAX_RETRIES", 3
 )
+
+# CATALOG MANAGER CONFIG
+PlatformCatalogManagerConfig = config["PlatformCatalogManager"]
+CATALOG_MODE = PlatformCatalogManagerConfig.getboolean("CATALOG_MODE", False)
+GET_CATALOG_REFRESH_PERIOD_SECONDS = PlatformCatalogManagerConfig.getint("GET_CATALOG_REFRESH_PERIOD_SECONDS", 60)
+GET_CATALOG_MAX_RETRIES = PlatformCatalogManagerConfig.getint("GET_CATALOG_MAX_RETRIES", 5)
+
+
+
