@@ -1,6 +1,7 @@
 import { ILabShell, JupyterFrontEnd, JupyterFrontEndPlugin } from '@jupyterlab/application';
 import { ClusterStore } from './store';
 import { ToolbarExtension } from './toolbar';
+import { cellFactory } from './cellSelect';
 import '../style/index.css';
 
 import { LabIcon } from '@jupyterlab/ui-components';
@@ -13,7 +14,7 @@ const activate = (app: JupyterFrontEnd, labShell: ILabShell): void => {
   const _cluster_store = new ClusterStore();
 
   // Toolbar (select cluster from inside notebook)
-  app.docRegistry.addWidgetExtension('Notebook', new ToolbarExtension(_cluster_store));
+  app.docRegistry.addWidgetExtension('Notebook', new ToolbarExtension(_cluster_store, null));
   // Sidebar to display clusters
   const sidebar = new BodoClusterListSidebar(_cluster_store);
   sidebar.id = 'bodo-cluster-list';
@@ -29,11 +30,14 @@ const activate = (app: JupyterFrontEnd, labShell: ILabShell): void => {
 /**
  * Initialization for the bodo-jupyterlab extension.
  */
-const plugin: JupyterFrontEndPlugin<void> = {
-  id: 'bodo-labextension:plugin',
-  autoStart: true,
-  requires: [ILabShell],
-  activate,
-};
+const plugins: JupyterFrontEndPlugin<any>[] = [
+  {
+    id: 'bodo-labextension:plugin',
+    autoStart: true,
+    requires: [ILabShell],
+    activate,
+  },
+  cellFactory,
+];
 
-export default plugin;
+export default plugins;
