@@ -1,14 +1,20 @@
+/* This file creates custom dropdowns and additions to the jupyter notebook toolbar
+ * including the cluster attach dropdown and the catalog select dropdown (controlled by a feature flag).
+ * */
+
+import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
 import { ISessionContext, ReactWidget, showErrorMessage } from '@jupyterlab/apputils';
 import { DocumentRegistry } from '@jupyterlab/docregistry';
 import { INotebookModel, NotebookPanel } from '@jupyterlab/notebook';
 import { IDisposable, DisposableDelegate } from '@lumino/disposable';
 import { IChangedArgs } from '@jupyterlab/coreutils';
-import { createRemoteIKernelHandler } from './handler';
+import { catalogModeHandler, createRemoteIKernelHandler } from './handler';
 import * as React from 'react';
 import { ClusterStore } from './store';
 import { ICluster } from './types';
 import ClusterSelectList from './clusterSelect';
 import { shouldAutoAttachHandler } from './handler';
+import { CatalogsSelect } from './catalogSelect';
 
 interface IProps {
   store: ClusterStore;
@@ -53,7 +59,7 @@ class ClusterSelect extends React.Component<IProps, IState> {
       console.debug('Session Change New Kernel Name: ', newSession.newValue._kernel._name);
       this.props.getClusterUUIDFromKernel(newSession.newValue._kernel._name).then(
         (clusterUUID) => {
-          const clusterFromKernel = clusters.find((cluster) => cluster.uuid);
+          const clusterFromKernel = clusters.find((cluster) => cluster.uuid === clusterUUID);
           if (clusterFromKernel && clusterFromKernel.status === 'RUNNING') {
             console.debug('Found cluster for this kernel: ', clusterUUID);
             this.setState({ currentClusterUUID: clusterUUID });
@@ -172,9 +178,24 @@ export class ToolbarExtension
   implements DocumentRegistry.IWidgetExtension<NotebookPanel, INotebookModel>
 {
   private _store: ClusterStore;
+  // Feature flag that controls whether catalogs are enabled.
+  private _catalog_mode: boolean | null;
 
-  constructor(store: ClusterStore) {
+  constructor(store: ClusterStore, catalog_mode: boolean | null) {
     this._store = store;
+    this._catalog_mode = catalog_mode;
+    // Catalog mode is picked up from configuration, where it is set using
+    // the default notebook config built from
+    // the backend. True if AWS or non-pro environments for now.
+    this._setCatalogMode();
+  }
+
+  async _setCatalogMode(): Promise<void> {
+    let catalogmode = this._catalog_mode;
+    if (catalogmode === null) {
+      catalogmode = await catalogModeHandler();
+    }
+    this._catalog_mode = catalogmode;
   }
 
   createNew(panel: NotebookPanel, context: DocumentRegistry.IContext<INotebookModel>): IDisposable {
@@ -238,19 +259,36 @@ export class ToolbarExtension
       return null;
     };
 
-    const dropdown = ReactWidget.create(
-      <ClusterSelect
-        store={this._store}
-        startKernelForCluster={startKernelForCluster}
-        getClusterUUIDFromKernel={getClusterUUIDFromKernel}
-        sessionContext={context.sessionContext}
-      />
+    const queryClient = new QueryClient();
+
+    const clusterSelectDropdown = ReactWidget.create(
+      <QueryClientProvider client={queryClient}>
+        <ClusterSelect
+          store={this._store}
+          startKernelForCluster={startKernelForCluster}
+          getClusterUUIDFromKernel={getClusterUUIDFromKernel}
+          sessionContext={context.sessionContext}
+        />
+      </QueryClientProvider>
     );
 
-    panel.toolbar.insertItem(0, 'clusterSelect', dropdown);
+    const catalogSelectDropdown = ReactWidget.create(
+      <QueryClientProvider client={queryClient}>
+        <CatalogsSelect panel={panel} />
+      </QueryClientProvider>
+    );
+
+    panel.toolbar.insertItem(0, 'clusterSelect', clusterSelectDropdown);
+    const enable_catalog = this._catalog_mode;
+    if (enable_catalog) {
+      panel.toolbar.insertItem(10, 'catalogSelect', catalogSelectDropdown);
+    }
 
     return new DisposableDelegate(() => {
-      dropdown.dispose();
+      clusterSelectDropdown.dispose();
+      if (enable_catalog) {
+        catalogSelectDropdown.dispose();
+      }
     });
   }
 }
